# TestNewBareProject_Bare0

Project TestNewBareProject_Bare0 is generated by [`horn-py`](https://github.com/bigfang/horn-py)

## Development Environment
To start your server:

  * Install dependencies with `poetry install`
  * Start flask server with `FLASK_ENV=development FLASK_APP=app poetry run flask run`

Visit API: [`localhost:5000/api`](http://localhost:5000/api)

Visit Swagger-UI: [`localhost:5000/spec`](http://localhost:5000/spec)

## Production Environment
To start your server:

  * Install dependencies with `poetry install --extras pg`
  * Start flask server with `FLASK_APP=app poetry run flask run`

Visit API: [`localhost:5000/api`](http://localhost:5000/api)

## Learn more

  * Flask: http://flask.pocoo.org
  * Marshmallow: https://marshmallow.readthedocs.io
  * SQLAlchemy: https://www.sqlalchemy.org
  * horn-py: https://github.com/bigfang/horn-py
